==> ockam_node_attribute-0.12.0.crate: ockam_node_attribute-0.12.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.12.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-26
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.7.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.6.0 - 2021-06-30
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.4.0 - 2021-06-14
### Changed
- Dependencies updated.

## v0.3.0 - 2021-05-30
### Added
### Changed
- Dependencies updated.
- Fixed clippy issues.

## v0.1.8 - 2021-05-10
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.1.7 - 2021-05-03
### Changed
- Dependencies updated.

## v0.1.6 - 2021-04-26
### Changed
- Dependencies updated.

## v0.1.5 - 2021-04-12
### Changed
- Dependencies updated.

## v0.1.4 - 2021-02-03
### Changed

- Increased validation of macro parameters.
- Documentation edits.

## v0.1.3 - 2021-02-03
### Changed

- Fix repository URL in Cargo.toml

## v0.1.2 - 2021-01-30
### Changed

- README

## v0.1.1 - 2021-01-30
### Changed

- README and docs

## v0.1.0 - 2021-01-30
### Added

- `node` - a proc macro that defines a custom `#[node]` attribute.

==> ockam_node_attribute-0.15.0.crate: ockam_node_attribute-0.15.0/CHANGELOG.md <==
# Changelog

All notable changes to this crate will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.15.0 - 2021-08-23
### Changed
- Replace std:: modules with core:: and alternate implementations
- Dependencies updated.

## v0.14.0 - 2021-08-16
### Changed
- Dependencies updated.

## v0.13.0 - 2021-08-09
### Changed
- Dependencies updated.

## v0.12.0 - 2021-08-03
### Changed
- Dependencies updated.

## v0.11.0 - 2021-07-29
### Changed
- Dependencies updated.

## v0.10.0 - 2021-07-26
### Changed
- Dependencies updated.

## v0.9.0 - 2021-07-19
### Changed
- Dependencies updated.

## v0.8.0 - 2021-07-12
### Changed
- Dependencies updated.

## v0.7.0 - 2021-07-06
### Changed
- Dependencies updated.

## v0.6.0 - 2021-06-30
### Changed
- Dependencies updated.

## v0.5.0 - 2021-06-21
### Changed
- Dependencies updated.

## v0.4.0 - 2021-06-14
### Changed
- Dependencies updated.

## v0.3.0 - 2021-05-30
### Added
### Changed
- Dependencies updated.
- Fixed clippy issues.

## v0.1.8 - 2021-05-10
### Added
### Changed
- Dependencies updated.
### Deleted

## v0.1.7 - 2021-05-03
### Changed
- Dependencies updated.

## v0.1.6 - 2021-04-26
### Changed
- Dependencies updated.

## v0.1.5 - 2021-04-12
### Changed
- Dependencies updated.

## v0.1.4 - 2021-02-03
### Changed

- Increased validation of macro parameters.
- Documentation edits.

## v0.1.3 - 2021-02-03
### Changed

- Fix repository URL in Cargo.toml

## v0.1.2 - 2021-01-30
### Changed

- README

## v0.1.1 - 2021-01-30
### Changed

- README and docs

## v0.1.0 - 2021-01-30
### Added

- `node` - a proc macro that defines a custom `#[node]` attribute.
